@@ -1,5 +1,5 @@
 #!/bin/sh
-# $Id: update-inetd.sh,v 1.2 2002/01/29 20:13:25 robert Exp $
+# $Id: update-inetd.sh,v 1.3 2005/01/04 17:13:12 robert Exp $
 #
 # rlinetd's version of update-inetd.
 # Robert Luberda <robert@debian.org>, Aug 2001
@@ -9,14 +9,14 @@ set -e
 
 PATH=/usr/sbin:$PATH
 
-version='$Revision: 1.2 $'
+version='$Revision: 1.3 $'
 line=""
 last=""
 
 for i in "$@" ; do
 	case "$i" in
 		"--remove"|"--disable"|"--enable")
-			echo "Warning: Operation  $1 is not supported by rlinetd's version of update-inetd" 1>&2
+			echo "Warning: Operation  $i is not supported by rlinetd's version of update-inetd" 1>&2
 			;;
 		"--version")
 			echo "rlinetd's version of update-inetd"
@@ -24,7 +24,7 @@ for i in "$@" ; do
 			exit 0
 			;;
 		*)	if [ "x$last" = "x--add" ] ; then
-				line="$line\n$1"
+				line="$i"
 			fi
 			;;
 	esac
