@@ -16,4 +16,12 @@ int snprintf(char *, size_t, const char *, ...);
 int vsnprintf(char *, size_t, const char *, va_list);
 #endif
 
+#ifdef HAVE_STAT_EMPTY_STRING_BUG
+# define stat rpl_stat
+#endif
+
+#ifdef HAVE_LSTAT_EMPTY_STRING_BUG
+# define lstat rpl_lstat
+#endif
+
 #endif /* !H_PORT */
